Package: urca
Version: 1.3-4
Date: 2024-05-25
Title: Unit Root and Cointegration Tests for Time Series Data
Authors@R: c(person("Bernhard", "Pfaff", email = "bernhard@pfaffikus.de", role = c("aut", "cre")), person("Eric", "Zivot",email = "ezivot@u.washington.edu", role = "ctb"), person("Matthieu", "Stigler", role = "ctb"))
Depends: R (>= 2.0.0), methods
Imports: nlme, graphics, stats
LazyLoad: yes
Description: Unit root and cointegration tests encountered in applied 
 econometric analysis are implemented.
License: GPL (>= 2)
NeedsCompilation: yes
Packaged: 2024-05-25 16:28:23 UTC; bp
Author: Bernhard Pfaff [aut, cre],
  Eric Zivot [ctb],
  Matthieu Stigler [ctb]
Maintainer: Bernhard Pfaff <bernhard@pfaffikus.de>
Repository: CRAN
Date/Publication: 2024-05-27 12:20:03 UTC
Built: R 4.6.0; aarch64-apple-darwin23; 2026-04-26 02:19:51 UTC; unix
Archs: urca.so.dSYM
