##
import(methods)
import(nlme)

##
useDynLib(urca, .registration = TRUE)

## Functions
export(ablrtest, alphaols, alrtest, blrtest, bh5lrtest, bh6lrtest, ca.jo, ca.po,
       cajolst, cajools, cajorls, lttest, plotres, punitroot, qunitroot, unitrootTable,
       ur.ers, ur.kpss, ur.pp, ur.df, ur.sp, ur.za)

## Classes       
exportClasses("urca", "ca.jo", "cajo.test", "ur.kpss", "ca.po", "ur.ers", "ur.pp", "ur.sp", "ur.df", "ur.za", "sumurca")

## Methods
exportMethods("show", "plot", "summary")

## Import functions
importFrom("graphics", "abline", "layout", "legend", "lines", "mtext",
           "par", "plot")
importFrom("stats", "AIC", "acf", "anova", "BIC", "coef", "embed", "formula",
           "lm", "na.omit", "pacf", "pchisq", "plot.ts", "resid", "residuals")

